#[repr(u32)]pub enum Value {
Disabled = 0,
Enabled = 1,
}Expand description
Receive enable. If this bit is set to 1, the receive section of the UART is enabled. Data reception occurs for either UART signals or SIR signals depending on the setting of the SIREN bit. When the UART is disabled in the middle of reception, it completes the current character before stopping.
Variants